@@ -1,5 +1,4 @@
 #include "test.h"
-#include "dumb-box.h"
 
 #include <eel/eel-debug-drawing.h>
 
@@ -52,7 +51,6 @@ style_get_color (const GtkStyle *style,
 	empty.pixel = 0;
 
 	g_return_val_if_fail (style != NULL, empty);
-	g_return_val_if_fail (n >= 0, empty);
 	g_return_val_if_fail (n < NUM_COLORS, empty);
 	g_return_val_if_fail (state >= GTK_STATE_NORMAL, empty);
 	g_return_val_if_fail (state <= GTK_STATE_INSENSITIVE, empty);
@@ -67,7 +65,6 @@ style_get_color (const GtkStyle *style,
 	case 6: return style->base[state];
 	}
 	g_return_val_if_reached (empty);
-	return empty;
 }
 
 static GdkGC *
@@ -76,7 +73,6 @@ style_get_gc (const GtkStyle *style,
 	      GtkStateType state)
 {
 	g_return_val_if_fail (style != NULL, NULL);
-	g_return_val_if_fail (n >= 0, NULL);
 	g_return_val_if_fail (n < NUM_COLORS, NULL);
 	g_return_val_if_fail (state >= GTK_STATE_NORMAL, NULL);
 	g_return_val_if_fail (state <= GTK_STATE_INSENSITIVE, NULL);
@@ -91,7 +87,6 @@ style_get_gc (const GtkStyle *style,
 	case 6: return style->base_gc[state];
 	}
 	g_return_val_if_reached (NULL);
-	return NULL;
 }
 
 static GdkPixmap *
@@ -112,19 +107,16 @@ color_box_expose_event (GtkWidget *widget,
 {
 	guint col;
 	guint row;
-	GtkWidget *child;
 	ArtIRect dirty_area;
 	GdkColor color;
 	GdkGC *gc;
 
- 	g_return_val_if_fail (GTK_IS_DUMB_BOX (widget), FALSE);
+ 	g_return_val_if_fail (GTK_IS_VBOX (widget), FALSE);
  	g_return_val_if_fail (event != NULL, FALSE);
 
 	col = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "col"));
 	row = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "row"));
 
-	child = GTK_BIN (widget)->child;
-
 	color = style_get_color (widget->style, row, col);
 
 	gc = gdk_gc_new (widget->window);
@@ -153,18 +145,15 @@ gc_box_expose_event (GtkWidget *widget,
 {
 	guint col;
 	guint row;
-	GtkWidget *child;
 	ArtIRect dirty_area;
 	GdkGC *gc;
 
- 	g_return_val_if_fail (GTK_IS_DUMB_BOX (widget), FALSE);
+ 	g_return_val_if_fail (GTK_IS_VBOX (widget), FALSE);
  	g_return_val_if_fail (event != NULL, FALSE);
 
 	col = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "col"));
 	row = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "row"));
 
-	child = GTK_BIN (widget)->child;
-
 	gc = style_get_gc (widget->style, row, col);
 	g_return_val_if_fail (gc != NULL, FALSE);
 
@@ -185,8 +174,6 @@ pixmap_box_expose_event (GtkWidget *widget,
 			 gpointer callback_data)
 {
 	guint col;
-	guint row;
-	GtkWidget *child;
 	ArtIRect dirty_area;
 	GdkPixmap *pixmap;
 	GdkPixbuf *pixbuf;
@@ -194,13 +181,10 @@ pixmap_box_expose_event (GtkWidget *widget,
 	int pixmap_height;
 	GdkGC *gc;
 
- 	g_return_val_if_fail (GTK_IS_DUMB_BOX (widget), FALSE);
+ 	g_return_val_if_fail (GTK_IS_VBOX (widget), FALSE);
  	g_return_val_if_fail (event != NULL, FALSE);
 
 	col = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "col"));
-	row = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "row"));
-
-	child = GTK_BIN (widget)->child;
 
 	pixmap = style_get_pixmap (widget->style, col);
 
@@ -335,7 +319,7 @@ main (int argc, char* argv[])
 
 	for (j = 0; j < NUM_COLORS; j++) {
 		for (i = 0; i < NUM_STATES; i++) {
-			colors_boxes[i][j] = eel_dumb_box_new ();
+			colors_boxes[i][j] = gtk_vbox_new (FALSE, 0);
 			gtk_widget_ensure_style (colors_boxes[i][j]);
 
 			g_signal_connect (colors_boxes[i][j],
@@ -418,7 +402,7 @@ main (int argc, char* argv[])
 
 	for (j = 0; j < NUM_GCS; j++) {
 		for (i = 0; i < NUM_STATES; i++) {
-			gcs_boxes[i][j] = eel_dumb_box_new ();
+			gcs_boxes[i][j] = gtk_vbox_new (FALSE, 0);
 			gtk_widget_ensure_style (gcs_boxes[i][j]);
 			
 			g_signal_connect (gcs_boxes[i][j],
@@ -500,7 +484,7 @@ main (int argc, char* argv[])
 
 	for (j = 0; j < NUM_PIXMAPS; j++) {
 		for (i = 0; i < NUM_STATES; i++) {
-			pixmaps_boxes[i][j] = eel_dumb_box_new ();
+			pixmaps_boxes[i][j] = gtk_vbox_new (FALSE, 0);
 			gtk_widget_ensure_style (pixmaps_boxes[i][j]);
 
 			g_signal_connect (pixmaps_boxes[i][j],
